@@ -119,6 +119,7 @@ class CGSmartImage extends CGExtensions
     $this->CreateParameter('filter_pixelate','',$this->Lang('param_filter_pixelate'));
     $this->CreateParameter('filter_resize','',$this->Lang('param_filter_resize'));
     $this->CreateParameter('filter_rotate','',$this->Lang('param_filter_rotate'));
+    $this->CreateParameter('filter_roundedcorners','',$this->Lang('param_filter_roundedcorners'));
     $this->CreateParameter('filter_watermark','',$this->Lang('param_filter_watermark'));
 
     $this->RegisterModulePlugin();
@@ -147,7 +148,7 @@ class CGSmartImage extends CGExtensions
    ---------------------------------------------------------*/
   function GetVersion()
   {
-    return '1.1';
+    return '1.2.1';
   }
 
   
@@ -156,7 +157,7 @@ class CGSmartImage extends CGExtensions
    ---------------------------------------------------------*/
   function MinimumCMSVersion()
   {
-    return '1.9.1';
+    return '1.9.2';
   }
 
 
@@ -165,7 +166,7 @@ class CGSmartImage extends CGExtensions
    ---------------------------------------------------------*/
   function GetDependencies()
   {
-    return array('CGExtensions'=>'1.23.1');
+    return array('CGExtensions'=>'1.25.2');
   }
 
 
@@ -295,9 +296,9 @@ class CGSmartImage extends CGExtensions
       {
       case Browser::BROWSER_IE:
 	$ver = $browser->getVersion();
-	if( $ver < 7 ) return FALSE;
+	if( $ver <= 7 ) return FALSE;
 	if( $CMS_STYLESHEET && $ver < 8 ) return FALSE;
-	if( $ver == 7 && $imagesize <= 32*1024 ) return TRUE;
+	if( $ver == 8 && $imagsize >= 32*1024 ) return FALSE;
 	return TRUE;
 
       default:
